==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/menu/admin_menu.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_menu.lang.inc.php 2020-02-03
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'BOX_ADMIN_ACCESS'            => 'Rollen und Berechtigungen',
    'BOX_GAMBIO_STORE'       => 'Gambio Store',
    'BOX_ATTRIBUTES_MANAGER'      => 'Attributverwaltung',
    'BOX_BACKUP'                  => 'Datenbanksicherung',
    'BOX_BANNER_MANAGER'          => 'Banner Manager',
    'BOX_CACHE'                   => 'Cache',
    'BOX_CAMPAIGNS'               => 'Kampagnen',
    'BOX_CAMPAIGNS_REPORT'        => 'Kampagnen Report',
    'BOX_CATEGORIES'              => 'Artikel / Kategorien',
    'BOX_CLEAR_CACHE'             => 'Cache leeren',
    'BOX_CONFIGURATION_1'         => 'Mein Shop',
    'BOX_CONFIGURATION_10'        => 'Logging-Optionen',
    'BOX_CONFIGURATION_11'        => 'Cache-Optionen',
    'BOX_CONFIGURATION_12'        => 'E-Mail-Optionen',
    'BOX_CONFIGURATION_13'        => 'Download-Optionen',
    'BOX_CONFIGURATION_14'        => 'Performance',
    'BOX_CONFIGURATION_15'        => 'Sessions',
    'BOX_CONFIGURATION_17'        => 'Zusatzmodule',
    'BOX_CONFIGURATION_18'        => 'USt-IdNr.',
    'BOX_CONFIGURATION_19'        => 'Schnittstellen',
    'BOX_CONFIGURATION_2'         => 'Minimum Werte',
    'BOX_CONFIGURATION_22'        => 'Such-Optionen',
    'BOX_CONFIGURATION_3'         => 'Maximum Werte',
    'BOX_CONFIGURATION_4'         => 'Bild-Optionen',
    'BOX_CONFIGURATION_5'         => 'Kunden-Details',
    'BOX_CONFIGURATION_7'         => 'Versand-Optionen',
    'BOX_CONFIGURATION_753'       => 'Shop-Key',
    'BOX_CONFIGURATION_8'         => 'Artikelübersicht-Optionen',
    'BOX_CONFIGURATION_9'         => 'Lagerverwaltungs-Optionen',
    'BOX_CONTENT'                 => 'Content Manager',
    'BOX_COUNTRIES'               => 'Länder',
    'BOX_COUPON_ADMIN'            => 'Rabatt Coupons',
    'BOX_CRONJOBS'                => 'Zeitgesteuerte Aufgaben',
    'BOX_CURRENCIES'              => 'Währungen',
    'BOX_CUSTOMERS'               => 'Kunden',
    'BOX_CUSTOMERS_STATUS'        => 'Kundengruppen',
    'BOX_EMAILS'                  => 'E-Mails',
    'BOX_ERROR_PAGES'             => 'Eigene Fehlerseiten',
    'BOX_FILEMANAGER'             => 'Dateimanager',
    'BOX_FORM_EDITOR'             => 'Formular-Editor',
    'BOX_GEO_ZONES'               => 'Steuerzonen',
    'BOX_GM_ANALYTICS'            => 'Tracking-Codes',
    'BOX_GM_BACKUP_FILES_ZIP'     => 'Dateien sichern',
    'BOX_GM_COUNTER'              => 'Besucherstatistik',
    'BOX_GM_EMAILS'               => 'E-Mail Vorlagen',
    'BOX_GM_FEATURE_CONTROL'      => 'Artikel-Filter',
    'BOX_GM_GPRINT'               => 'GX-Customizer',
    'BOX_GM_GUESTBOOK'            => 'Gästebuch',
    'BOX_GM_ID_STARTS'            => 'Nummernkreise',
    'BOX_GM_JANOLAW'              => 'janolaw AGB Hosting',
    'BOX_GM_LANG_EDIT'            => 'Texte anpassen',
    'BOX_GM_LAWS'                 => 'Rechtliches',
    'BOX_GM_LIGHTBOX'             => 'Lightbox Konfiguration',
    'BOX_GM_LOGO'                 => 'Logo Manager',
    'BOX_GM_META'                 => 'Meta-Angaben',
    'BOX_GM_MISCELLANEOUS'        => 'Allgemeines',
    'BOX_GM_MODULE_EXPORT'        => 'Kundenexport',
    'BOX_GM_OFFLINE'              => 'Shop online/offline',
    'BOX_GM_PDF'                  => 'Rechnung/Lieferschein',
    'BOX_GM_PRODUCT_EXPORT'       => 'Artikelexport',
    'BOX_GM_SECURITY'             => 'Sicherheitscenter',
    'BOX_GM_SEO_BOOST'            => 'Gambio SEO Boost',
    'BOX_GM_SITEMAP'              => 'Sitemap Generator',
    'BOX_GM_SLIDER'               => 'Teaser-Slider',
    'BOX_GM_SQL'                  => 'SQL',
    'BOX_GM_STYLE_EDIT'           => 'Template-Einstellungen',
    'BOX_GM_TRUSTED_SHOP_ID'      => 'Trusted Shops Gütesiegel',
    'BOX_GV_ADMIN_MAIL'           => 'Gutschein E-Mail',
    'BOX_GV_ADMIN_QUEUE'          => 'Gutschein Queue',
    'BOX_GV_ADMIN_SENT'           => 'Gutscheine versandt',
    'BOX_GV_CONFIG'               => 'Gutschein-Konfiguration',
    'BOX_HEADING_CONFIGURATION'   => 'Konfiguration',
    'BOX_HEADING_CUSTOMERS'       => 'Kunden',
    'BOX_HEADING_FAVS'            => 'Favs',
    'BOX_HEADING_GAMBIO_SEO'      => 'Gambio SEO',
    'BOX_HEADING_GV_ADMIN'        => 'Gutscheine',
    'BOX_HEADING_LAYOUT_DESIGN'   => 'Darstellung',
    'BOX_HEADING_MODULES'         => 'Module',
    'BOX_HEADING_PRODUCTS'        => 'Artikel',
    'BOX_HEADING_SHOP_SETTINGS'   => 'Shop Einstellungen',
    'BOX_HEADING_STATISTICS'      => 'Statistiken',
    'BOX_HEADING_SYSTEM_SETTINGS' => 'System Einstellungen',
    'BOX_HEADING_TOOLS'           => 'Toolbox',
    'BOX_HEADING_ZONE'            => 'Land/Steuer',
    'BOX_IMPORT'                  => 'Artikeldaten',
    'BOX_IMPORT_OLD'              => 'Artikeldaten (alt)',
    'BOX_INVOICES'                => 'Rechnungen',
    'BOX_LANGUAGES'               => 'Sprachen',
    'BOX_MAILBEEZ'                => 'MailBeez Email-Marketing',
    'BOX_MAILBEEZ_SHOPVOTING'     => 'Shopbewertungen',
    'BOX_MANUFACTURERS'           => 'Hersteller',
    'BOX_MODULE_EXPORT'           => 'Modul-Center',
    'BOX_MODULE_NEWSLETTER'       => 'Newsletter',
    'BOX_ORDER_TOTAL'             => 'Zusammenfassung',
    'BOX_ORDERS'                  => 'Bestellungen',
    'BOX_ORDERS_OLD'              => 'Bestellungen (alte Version)',
    'BOX_ORDERS_STATUS'           => 'Bestellstatus',
    'BOX_ORDERS_XSELL_GROUP'      => 'Cross-Marketing Gruppen',
    'BOX_PARCEL_SERVICES'         => 'Paketdienste',
    'BOX_PAYMENT'                 => 'Zahlungsweisen',
    'BOX_PAYPAL'                  => 'PayPal',
    'BOX_PRODUCTS_ATTRIBUTES'     => 'Artikelattribute',
    'BOX_PRODUCTS_PURCHASED'      => 'Verkaufte Artikel',
    'BOX_PRODUCTS_VIEWED'         => 'Besuchte Artikel',
    'BOX_PRODUCTS_VPE'            => 'Verpackungseinheiten',
    'BOX_PROPERTIES'              => 'Artikeleigenschaften',
    'BOX_QUANTITYUNITS'           => 'Mengeneinheiten',
    'BOX_QUICK_EDIT'              => 'QuickEdit',
    'BOX_REVIEWS'                 => 'Kundenrezensionen',
    'BOX_ROBOTS'                  => 'Robots Datei',
    'BOX_SALES_REPORT'            => 'Umsatzstatistik',
    'BOX_SERVER_INFO'             => 'Server Info',
    'BOX_SHIPPING'                => 'Versandarten',
    'BOX_SHIPPING_STATUS'         => 'Lieferstatus',
    'BOX_SHOP_SETTINGS'           => 'Shop Einstellungen',
    'BOX_SHOW_LOGS'               => 'Logs anzeigen',
    'BOX_SHOW_LOGS_LEGACY'        => 'Logs anzeigen (veraltet)',
    'BOX_SPECIALS'                => 'Sonderangebote',
    'BOX_STATIC_SEO_URLS'         => 'Statische Seiten',
    'BOX_STATS_CUSTOMERS'         => 'Kunden-Bestellstatistik',
    'BOX_SYSTEM_SETTINGS'         => 'System Einstellungen',
    'BOX_TAX_CLASSES'             => 'Steuerklassen',
    'BOX_TAX_RATES'               => 'Steuersätze',
    'BOX_TIMER'                   => 'Timer',
    'BOX_TOOLS_BLACKLIST'         => 'Kreditkarten sperren',
    'BOX_VERSION_HISTORY'         => 'Version History',
    'BOX_WHOS_ONLINE'             => 'Wer ist online?',
    'BOX_WITHDRAWALS'             => 'Widerrufe',
    'BOX_YATEGO'                  => 'Yatego',
    'BOX_YOOCHOOSE'               => 'YOOCHOOSE Empfehlungen',
    'BOX_ZONES'                   => 'Bundesländer',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/menu/admin_menu.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_menu.lang.inc.php 2021-08-13
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2021 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'BOX_ADMIN_ACCESS'            => 'Rollen und Berechtigungen',
    'BOX_GAMBIO_STORE'            => 'Gambio Store',
    'BOX_ATTRIBUTES_MANAGER'      => 'Attributverwaltung',
    'BOX_BACKUP'                  => 'Datenbanksicherung',
    'BOX_BANNER_MANAGER'          => 'Banner Manager',
    'BOX_CACHE'                   => 'Cache',
    'BOX_CAMPAIGNS'               => 'Kampagnen',
    'BOX_CAMPAIGNS_REPORT'        => 'Kampagnen Report',
    'BOX_CATEGORIES'              => 'Artikel / Kategorien',
    'BOX_CLEAR_CACHE'             => 'Cache leeren',
    'BOX_CONFIGURATION_1'         => 'Mein Shop',
    'BOX_CONFIGURATION_10'        => 'Logging-Optionen',
    'BOX_CONFIGURATION_11'        => 'Cache-Optionen',
    'BOX_CONFIGURATION_12'        => 'E-Mail-Optionen',
    'BOX_CONFIGURATION_13'        => 'Download-Optionen',
    'BOX_CONFIGURATION_14'        => 'Performance',
    'BOX_CONFIGURATION_15'        => 'Sessions',
    'BOX_CONFIGURATION_17'        => 'Zusatzmodule',
    'BOX_CONFIGURATION_18'        => 'USt-IdNr.',
    'BOX_CONFIGURATION_19'        => 'Schnittstellen',
    'BOX_CONFIGURATION_2'         => 'Minimum Werte',
    'BOX_CONFIGURATION_22'        => 'Such-Optionen',
    'BOX_CONFIGURATION_3'         => 'Maximum Werte',
    'BOX_CONFIGURATION_4'         => 'Bild-Optionen',
    'BOX_CONFIGURATION_5'         => 'Kunden-Details',
    'BOX_CONFIGURATION_7'         => 'Versand-Optionen',
    'BOX_CONFIGURATION_753'       => 'Shop-Key',
    'BOX_CONFIGURATION_8'         => 'Artikelübersicht-Optionen',
    'BOX_CONFIGURATION_9'         => 'Lagerverwaltungs-Optionen',
    'BOX_CONTENT'                 => 'Content Manager',
    'BOX_COUNTRIES'               => 'Länder',
    'BOX_COUPON_ADMIN'            => 'Rabatt Coupons',
    'BOX_CRONJOBS'                => 'Zeitgesteuerte Aufgaben',
    'BOX_CURRENCIES'              => 'Währungen',
    'BOX_CUSTOMERS'               => 'Kunden',
    'BOX_CUSTOMERS_STATUS'        => 'Kundengruppen',
    'BOX_EMAILS'                  => 'E-Mails',
    'BOX_ERROR_PAGES'             => 'Eigene Fehlerseiten',
    'BOX_FILEMANAGER'             => 'Dateimanager',
    'BOX_FORM_EDITOR'             => 'Formular-Editor',
    'BOX_GEO_ZONES'               => 'Steuerzonen',
    'BOX_GM_ANALYTICS'            => 'Tracking-Codes',
    'BOX_GM_BACKUP_FILES_ZIP'     => 'Dateien sichern',
    'BOX_GM_COUNTER'              => 'Besucherstatistik',
    'BOX_GM_EMAILS'               => 'E-Mail Vorlagen',
    'BOX_GM_FEATURE_CONTROL'      => 'Artikel-Filter',
    'BOX_GM_GPRINT'               => 'GX-Customizer',
    'BOX_GM_ID_STARTS'            => 'Nummernkreise',
    'BOX_GM_JANOLAW'              => 'janolaw AGB Hosting',
    'BOX_GM_LANG_EDIT'            => 'Texte anpassen',
    'BOX_GM_LAWS'                 => 'Rechtliches',
    'BOX_GM_LIGHTBOX'             => 'Lightbox Konfiguration',
    'BOX_GM_LOGO'                 => 'Logo Manager',
    'BOX_GM_META'                 => 'Meta-Angaben',
    'BOX_GM_MISCELLANEOUS'        => 'Allgemeines',
    'BOX_GM_MODULE_EXPORT'        => 'Kundenexport',
    'BOX_GM_OFFLINE'              => 'Shop online/offline',
    'BOX_GM_PDF'                  => 'Rechnung/Lieferschein',
    'BOX_GM_PRODUCT_EXPORT'       => 'Artikelexport',
    'BOX_GM_SECURITY'             => 'Sicherheitscenter',
    'BOX_GM_SEO_BOOST'            => 'Gambio SEO Boost',
    'BOX_GM_SITEMAP'              => 'Sitemap Generator',
    'BOX_GM_SLIDER'               => 'Teaser-Slider',
    'BOX_GM_SQL'                  => 'SQL',
    'BOX_GM_STYLE_EDIT'           => 'Theme bearbeiten',
    'BOX_GM_TRUSTED_SHOP_ID'      => 'Trusted Shops Gütesiegel',
    'BOX_GV_ADMIN_MAIL'           => 'Gutschein E-Mail',
    'BOX_GV_ADMIN_QUEUE'          => 'Gutschein Queue',
    'BOX_GV_ADMIN_SENT'           => 'Gutscheine versandt',
    'BOX_GV_CONFIG'               => 'Gutschein-Konfiguration',
    'BOX_HEADING_CONFIGURATION'   => 'Konfiguration',
    'BOX_HEADING_CUSTOMERS'       => 'Kunden',
    'BOX_HEADING_FAVS'            => 'Favs',
    'BOX_HEADING_GAMBIO_SEO'      => 'Gambio SEO',
    'BOX_HEADING_GV_ADMIN'        => 'Gutscheine',
    'BOX_HEADING_LAYOUT_DESIGN'   => 'Inhalte',
    'BOX_HEADING_MODULES'         => 'Module',
    'BOX_HEADING_PRODUCTS'        => 'Artikel',
    'BOX_HEADING_SHOP_SETTINGS'   => 'Shop Einstellungen',
    'BOX_HEADING_STATISTICS'      => 'Statistiken',
    'BOX_HEADING_SYSTEM_SETTINGS' => 'System Einstellungen',
    'BOX_HEADING_TOOLS'           => 'Toolbox',
    'BOX_HEADING_ZONE'            => 'Land/Steuer',
    'BOX_IMPORT'                  => 'Import/Export',
    'BOX_IMPORT_OLD'              => 'Artikeldaten (alt)',
    'BOX_INVOICES'                => 'Rechnungen',
    'BOX_LANGUAGES'               => 'Sprachen',
    'BOX_MAILBEEZ'                => 'MailBeez Email-Marketing',
    'BOX_MAILBEEZ_SHOPVOTING'     => 'Shopbewertungen',
    'BOX_MANUFACTURERS'           => 'Hersteller',
    'BOX_MODULE_EXPORT'           => 'Modul-Center',
    'BOX_MODULE_NEWSLETTER'       => 'Newsletter',
    'BOX_ORDER_TOTAL'             => 'Zusammenfassung',
    'BOX_ORDERS'                  => 'Bestellungen',
    'BOX_ORDERS_OLD'              => 'Bestellungen (alte Version)',
    'BOX_ORDERS_STATUS'           => 'Bestellstatus',
    'BOX_ORDERS_XSELL_GROUP'      => 'Cross-Marketing Gruppen',
    'BOX_PARCEL_SERVICES'         => 'Paketdienste',
    'BOX_PAYMENT'                 => 'Zahlungsweisen',
    'BOX_PAYPAL'                  => 'PayPal',
    'BOX_PRODUCTS_ATTRIBUTES'     => 'Artikelattribute',
    'BOX_PRODUCTS_PURCHASED'      => 'Verkaufte Artikel',
    'BOX_PRODUCTS_VIEWED'         => 'Besuchte Artikel',
    'BOX_PRODUCTS_VPE'            => 'Verpackungseinheiten',
    'BOX_QUANTITYUNITS'           => 'Mengeneinheiten',
    'BOX_QUICK_EDIT'              => 'QuickEdit',
    'BOX_REDIRECT_RULES'          => 'Weiterleitungsregeln',
    'BOX_REVIEWS'                 => 'Kundenrezensionen',
    'BOX_ROBOTS'                  => 'Robots Datei',
    'BOX_SALES_REPORT'            => 'Umsatzstatistik',
    'BOX_SERVER_INFO'             => 'Server Info',
    'BOX_SHIPPING'                => 'Versandarten',
    'BOX_SHIPPING_STATUS'         => 'Lieferstatus',
    'BOX_SHOP_SETTINGS'           => 'Einstellungen',
    'BOX_SHOW_LOGS'               => 'Logs anzeigen',
    'BOX_SHOW_LOGS_LEGACY'        => 'Logs anzeigen (veraltet)',
    'BOX_SPECIALS'                => 'Sonderangebote',
    'BOX_STATIC_SEO_URLS'         => 'Statische Seiten',
    'BOX_STATS_CUSTOMERS'         => 'Kunden-Bestellstatistik',
    'BOX_SYSTEM_SETTINGS'         => 'System Einstellungen',
    'BOX_TAX_CLASSES'             => 'Steuerklassen',
    'BOX_TAX_RATES'               => 'Steuersätze',
    'BOX_TIMER'                   => 'Timer',
    'BOX_TOOLS_BLACKLIST'         => 'Kreditkarten sperren',
    'BOX_VERSION_HISTORY'         => 'Version History',
    'BOX_WHOS_ONLINE'             => 'Wer ist online?',
    'BOX_WITHDRAWALS'             => 'Widerrufe',
    'BOX_YATEGO'                  => 'Yatego',
    'BOX_ZONES'                   => 'Bundesländer',
    'BOX_DELETE_STATS'            => 'Statistiken löschen',
    'BOX_DELETE_IMAGES'           => 'Artikelbilder löschen',
    'BOX_SHOW_STOCK'              => 'Lagerbestände anzeigen',
    'BOX_STATISTICS_OVERVIEW'     => 'Übersicht',
    'BOX_OPTIONS'                 => 'Optionen',
    'BOX_DOWNLOAD_OPTIONS'        => 'Downloads',
];
